@@ -13,6 +13,7 @@ var group__pw__keys =
     [ "PW_KEY_LIBRARY_NAME_DBUS", "group__pw__keys.html#ga32748e803174c4983e3f5378fcbe0e87", null ],
     [ "PW_KEY_OBJECT_PATH", "group__pw__keys.html#gaf7bfe4ca43d361fe707d51c4b4590423", null ],
     [ "PW_KEY_OBJECT_ID", "group__pw__keys.html#gaaa13a0c747a64ff4f80c68f383e6f479", null ],
+    [ "PW_KEY_OBJECT_SERIAL", "group__pw__keys.html#gaeacddc61cce1b3b44562edc0d11bcc85", null ],
     [ "PW_KEY_OBJECT_LINGER", "group__pw__keys.html#ga3d5bd6f00b3c9a8d89e42aa6c3f8cb58", null ],
     [ "PW_KEY_OBJECT_REGISTER", "group__pw__keys.html#ga615dfda75e0fc56ae2f2f18a6acdae9c", null ],
     [ "PW_KEY_CONFIG_PREFIX", "group__pw__keys.html#ga547e340cc89d32b3c2378ec365c23c6c", null ],
@@ -60,19 +61,24 @@ var group__pw__keys =
     [ "PW_KEY_NODE_LATENCY", "group__pw__keys.html#ga6d08c36bb4d3bcae49e822023a8089e2", null ],
     [ "PW_KEY_NODE_MAX_LATENCY", "group__pw__keys.html#gaad5f9ff2318f5ff7156b81e4efa4b9fc", null ],
     [ "PW_KEY_NODE_LOCK_QUANTUM", "group__pw__keys.html#ga7e12dd6c9dec4a345c8a2a62f138b5bf", null ],
+    [ "PW_KEY_NODE_FORCE_QUANTUM", "group__pw__keys.html#gaa50ce0bca22904a417a4e9d05f8face6", null ],
     [ "PW_KEY_NODE_RATE", "group__pw__keys.html#ga1acad010d64de1a1d5225a23f5409d93", null ],
     [ "PW_KEY_NODE_LOCK_RATE", "group__pw__keys.html#ga459ef9c4251e8d02af6e52ab24d99fc1", null ],
+    [ "PW_KEY_NODE_FORCE_RATE", "group__pw__keys.html#gaeef628080a6eccafdc8be112b745be62", null ],
     [ "PW_KEY_NODE_DONT_RECONNECT", "group__pw__keys.html#ga02774290763120baf89042785522c0c2", null ],
     [ "PW_KEY_NODE_ALWAYS_PROCESS", "group__pw__keys.html#ga832d4e7fcc412f53aea49186c6ff2c8b", null ],
     [ "PW_KEY_NODE_WANT_DRIVER", "group__pw__keys.html#ga44a2c0b545bb924fcd5e93f0ce0b126d", null ],
     [ "PW_KEY_NODE_PAUSE_ON_IDLE", "group__pw__keys.html#ga0fb0fbf1691bb6972434b61706c3217a", null ],
+    [ "PW_KEY_NODE_SUSPEND_ON_IDLE", "group__pw__keys.html#ga22e14d7d1ea3b1a8c1fe4305e680682b", null ],
     [ "PW_KEY_NODE_CACHE_PARAMS", "group__pw__keys.html#ga6a9a361b575634ed2b4040eefbd9799a", null ],
+    [ "PW_KEY_NODE_TRANSPORT_SYNC", "group__pw__keys.html#gaa039c0a911742213e239311ec73b623b", null ],
     [ "PW_KEY_NODE_DRIVER", "group__pw__keys.html#gac760a7d13f161fcc86e964ad23399180", null ],
     [ "PW_KEY_NODE_STREAM", "group__pw__keys.html#ga8ff654b149404ba9e46f02e376cf9dcc", null ],
     [ "PW_KEY_NODE_VIRTUAL", "group__pw__keys.html#gad47c9bd7ac42e326f5879cac7b73df6f", null ],
     [ "PW_KEY_NODE_PASSIVE", "group__pw__keys.html#ga79f57786e98b76caf777f856ce26092b", null ],
     [ "PW_KEY_NODE_LINK_GROUP", "group__pw__keys.html#ga30bf1394ef6129573c44fea7d3af880e", null ],
     [ "PW_KEY_NODE_NETWORK", "group__pw__keys.html#ga7cc45df5bd241b9bb924802082490449", null ],
+    [ "PW_KEY_NODE_TRIGGER", "group__pw__keys.html#ga0346a35752b5d7641d7cd7b146733abf", null ],
     [ "PW_KEY_PORT_ID", "group__pw__keys.html#ga94975808271e28be225a6fd6d7957762", null ],
     [ "PW_KEY_PORT_NAME", "group__pw__keys.html#ga086fc9bb9864325037b0bd2310816034", null ],
     [ "PW_KEY_PORT_DIRECTION", "group__pw__keys.html#ga4a25213dfcf1d7b7ded06ed9284f1a5f", null ],
@@ -107,6 +113,7 @@ var group__pw__keys =
     [ "PW_KEY_DEVICE_FORM_FACTOR", "group__pw__keys.html#ga2ce5cc947b2519113b1d96b4f599eae3", null ],
     [ "PW_KEY_DEVICE_BUS", "group__pw__keys.html#gac1cc4afb3e028b4d00231d615705adce", null ],
     [ "PW_KEY_DEVICE_SUBSYSTEM", "group__pw__keys.html#gaae4d17260ca60c2ab5e2c8d32b989d67", null ],
+    [ "PW_KEY_DEVICE_SYSFS_PATH", "group__pw__keys.html#ga0f69443cc159a424e5b4157745fc1556", null ],
     [ "PW_KEY_DEVICE_ICON", "group__pw__keys.html#gae735cebef63f5368aec0d1859890c5cb", null ],
     [ "PW_KEY_DEVICE_ICON_NAME", "group__pw__keys.html#ga2a53446671230c87420a0edd859e70c4", null ],
     [ "PW_KEY_DEVICE_INTENDED_ROLES", "group__pw__keys.html#gada09ee1ffbf8eb6eaf8bb5f0431fbccf", null ],
@@ -149,7 +156,9 @@ var group__pw__keys =
     [ "PW_KEY_AUDIO_RATE", "group__pw__keys.html#gaf4643e961de004488943e2ab0322ac4c", null ],
     [ "PW_KEY_AUDIO_CHANNELS", "group__pw__keys.html#ga7f63a5688e90b4d78e8db0c7a18bd959", null ],
     [ "PW_KEY_AUDIO_FORMAT", "group__pw__keys.html#ga0b13a2631ffb67076f67105d1ca347d6", null ],
+    [ "PW_KEY_AUDIO_ALLOWED_RATES", "group__pw__keys.html#gaa2674ee0552a3f30a0446eb0461741d6", null ],
     [ "PW_KEY_VIDEO_RATE", "group__pw__keys.html#gac353c9d9c3ed50ea98806f63f09f9456", null ],
     [ "PW_KEY_VIDEO_FORMAT", "group__pw__keys.html#ga38e8da2c19e9cd1acf5823865f6e9742", null ],
-    [ "PW_KEY_VIDEO_SIZE", "group__pw__keys.html#gacc4d098e86d0be0bfe469604c07f4009", null ]
+    [ "PW_KEY_VIDEO_SIZE", "group__pw__keys.html#gacc4d098e86d0be0bfe469604c07f4009", null ],
+    [ "PW_KEY_TARGET_OBJECT", "group__pw__keys.html#ga7983296afaca4d7edac60714fa92565b", null ]
 ];
\ No newline at end of file
